
The documentation of Plumbery
=============================

.. toctree::
   :maxdepth: 2

   readme
   overview
   using
   installing
   fittings
   contributing
   history
   Documentation extracted from the code <plumbery>


* :ref:`genindex`

